#!/bin/bash

##########################################################################
# INTERNATIONAL BUSINESS MACHINES CORPORATION PROVIDES THIS SOFTWARE ON 
# AN "AS IS" BASIS AND IBM DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED, 
# INCLUDING, BUT NOT LIMITED TO, THE WARRANTY OF NON-INFRINGEMENT AND THE
# IMPLIED WARRANTIES OF  MERCHANTABILITY OR FITNESS FOR A PARTICULAR 
# PURPOSE.  IBM SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
# SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR OPERATION OF
# THIS SOFTWARE.  IBM HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, 
# UPDATES, ENHANCEMENTS OR MODIFICATIONS TO THE SOFTWARE.
##########################################################################

scripts=`dirname $0`
scripts=`cd $scripts;pwd`

server=$1
osname=`ssh $server uname`

echo "###############################################"
echo "# Installing WAS DMgr on $server"
echo "# Operating System: $osname"
echo "###############################################"

if [ "$osname" = "Linux" ]; then
image=$DMGR_IMG_LINUX
fixpack=$DMGRFP_IMG_LINUX
fixpackid=was51_nd_fp1_linux 
cumfix=$DMGRCUMFIX_IMG_LINUX
cumfixid=was511_nd_cf1_linux
jdkfix=$JDKFIX_IMG_LINUX
jdkfixid=was511_jdk_linux_i386
fi

if [ "$osname" = "SunOS" ]; then
image=$DMGR_IMG_SOLARIS
fixpack=$DMGRFP_IMG_SOLARIS
fixpackid=was51_nd_fp1_solaris
cumfix=$DMGRCUMFIX_IMG_SOLARIS
cumfixid=was511_nd_cf1_solaris
jdkfix=$JDKFIX_IMG_SOLARIS
jdkfixid=was511_jdk_solaris
fi

if [ "$osname" = "AIX" ]; then
image=$DMGR_IMG_AIX
fixpack=$DMGRFP_IMG_AIX
fixpackid=was51_nd_fp1_aix
cumfix=$DMGRCUMFIX_IMG_AIX
cumfixid=was511_nd_cf1_aix
jdkfix=$JDKFIX_IMG_AIX
jdkfixid=was511_jdk_aix
fi

if [ "$image" = "" ]; then
   echo Unrecognized operating system: $osname
   exit 1;
fi

echo "###############################################"
echo "# Installing WAS DMgr on $server"
echo "###############################################"

echo "###############################################"
echo "# Synchronize time"
echo "###############################################"
ssh $server "ntpdate -s pool.ntp.org"

echo "###############################################"
echo "# Stopping Deployment Manager"
echo "###############################################"
$scripts/stopDMgr

echo "###############################################"
echo "# Cleaning Up Deployment Manager Installation"
echo "###############################################"
ssh $server "rm -fr $PATH_DMGR /root/vpd.properties /opt/_id /var/sadm/pkg/*WS* /usr/lib/objrepos/vpd.properties"

echo "###############################################"
echo "# Transfer Files for Base install"
echo "###############################################"
bn=`basename $image`
ssh $server "mkdir /opt/_id"
scp $image $server:/opt/_id/$bn
scp $scripts/dmgr.response $server:/opt/_id

echo "###############################################"
echo "# Unzipping Installation Image"
echo "###############################################"
ssh $server "unzip -q /opt/_id/$bn -d /opt/_id"

echo "###############################################"
echo "# Installing Dmgr"
echo "###############################################"
nodename=`echo $server | cut -d. -f1`
nodename=${nodename}Manager
ssh $server "/opt/_id/install -is:javahome /opt/_id/jdk/java  -options /opt/_id/dmgr.response -W nodeNameBean.nodeName=$nodename -W nodeNameBean.cellname=$CELLNAME -W nodeNameBean.hostName=$server"

echo ""
echo "###############################################"
echo "# Cleaning Up Installation"
echo "###############################################"
ssh $server "rm -fr /opt/_id"

echo "###############################################"
echo "# Transfer Files for fixpack install"
echo "###############################################"
bn=`basename $fixpack`
ssh $server "mkdir /opt/_id"
scp $fixpack $server:/opt/_id/$bn

echo "###############################################"
echo "# Unzipping Fixpack Installation Image"
echo "###############################################"
ssh $server "unzip -q /opt/_id/$bn -d /opt/_id"

echo "###############################################"
echo "# Installing Dmgr fixpack"
echo "###############################################"
ssh $server ". $PATH_DMGR/bin/setupCmdLine.sh && /opt/_id/updateSilent.sh -installDir $PATH_DMGR -fixpack -install -fixpackDir /opt/_id/fixpacks -fixpackID $fixpackid -skipIHS -skipMQ"

echo "###############################################"
echo "# Cleaning Up Installation"
echo "###############################################"
ssh $server "rm -fr /opt/_id"

echo "###############################################"
echo "# Transfer Files for cumfix install"
echo "###############################################"
bn=`basename $cumfix`
ssh $server "mkdir /opt/_id"
scp $cumfix $server:/opt/_id/$bn

echo "###############################################"
echo "# Unzipping CumFix Installation Image"
echo "###############################################"
ssh $server "unzip -q /opt/_id/$bn -d /opt/_id"

echo "###############################################"
echo "# Installing Dmgr CumFix"
echo "###############################################"
ssh $server ". $PATH_DMGR/bin/setupCmdLine.sh && /opt/_id/updateSilent.sh -installDir $PATH_DMGR -fixpack -install -fixpackDir /opt/_id/fixpacks -fixpackID $cumfixid -skipIHS -skipMQ"

echo "###############################################"
echo "# Cleaning Up Installation"
echo "###############################################"
ssh $server "rm -fr /opt/_id"

echo "###############################################"
echo "# Transfer Files for JDK fixpack install"
echo "###############################################"
bn=`basename $jdkfix`
ssh $server "mkdir /opt/_id"
scp $jdkfix $server:/opt/_id/$bn

echo "###############################################"
echo "# Unzipping JDK fixpack Installation Image"
echo "###############################################"
ssh $server "unzip -q /opt/_id/$bn -d /opt/_id"

echo "###############################################"
echo "# Installing JDK fixpack"
echo "###############################################"
ssh $server ". $PATH_DMGR/bin/setupCmdLine.sh && /opt/_id/updateSilent.sh -installDir $PATH_DMGR -fixpack -install -fixpackDir /opt/_id/fixpacks -fixpackID $jdkfixid -skipIHS -skipMQ"

echo "###############################################"
echo "# Cleaning Up Installation"
echo "###############################################"
ssh $server "rm -fr /opt/_id"

echo "###############################################"
echo "# Save Base WebSphere Installation"
echo "###############################################"
ssh $server "rm -f /opt/WebSphereDMgr.zip"
ssh $server "zip -qr /opt/WebSphereDMgr.zip $PATH_DMGR"

echo "###############################################"
echo "# Restarting Deployment Manager"
echo "###############################################"
$scripts/startDMgr

echo "###############################################"
echo "# Installation Complete"
echo "###############################################"
