#!/bin/bash

##########################################################################
# INTERNATIONAL BUSINESS MACHINES CORPORATION PROVIDES THIS SOFTWARE ON 
# AN "AS IS" BASIS AND IBM DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED, 
# INCLUDING, BUT NOT LIMITED TO, THE WARRANTY OF NON-INFRINGEMENT AND THE
# IMPLIED WARRANTIES OF  MERCHANTABILITY OR FITNESS FOR A PARTICULAR 
# PURPOSE.  IBM SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
# SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR OPERATION OF
# THIS SOFTWARE.  IBM HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, 
# UPDATES, ENHANCEMENTS OR MODIFICATIONS TO THE SOFTWARE.
##########################################################################

scripts=`dirname $0`
scripts=`cd $scripts;pwd`
. $scripts/serverConfig

server=$1
osname=`ssh $server uname`

echo "###############################################"
echo "# Installing WAS AppServer on $server"
echo "# Operating System: $osname"
echo "###############################################"

if [ "$osname" = "Linux" ]; then
image=$BASE_IMG_LINUX
fixpack=$FP_IMG_LINUX
fixpackid=was51_fp1_linux
cumfix=$CUMFIX_IMG_LINUX
cumfixid=was511_cf1_linux 
jdkfix=$JDKFIX_IMG_LINUX
jdkfixid=was511_jdk_linux_i386 
fi

if [ "$osname" = "AIX" ]; then
image=$BASE_IMG_AIX
fixpack=$FP_IMG_AIX
fixpackid=was51_fp1_aix
cumfix=$CUMFIX_IMG_AIX
cumfixid=was511_cf1_aix 
jdkfix=$JDKFIX_IMG_AIX
jdkfixid=was511_jdk_aix 
fi

if [ "$osname" = "SunOS" ]; then
image=$BASE_IMG_SOLARIS
fixpack=$FP_IMG_SOLARIS
fixpackid=was51_fp1_solaris
cumfix=$CUMFIX_IMG_SOLARIS
cumfixid=was511_cf1_solaris
jdkfix=$JDKFIX_IMG_SOLARIS
jdkfixid=was511_jdk_solaris
fi

if [ "$image" = "" ]; then
echo Unsupported Operating System: $osname
exit 1
fi

echo "###############################################"
echo "# Synchronize time"
echo "###############################################"
ssh $server "ntpdate -s pool.ntp.org"

echo "###############################################"
echo "# Stopping node"
echo "###############################################"
$scripts/stopNode $1

echo "###############################################"
echo "# Cleaning Up AppServer Installation"
echo "###############################################"
ssh $server "rm -fr $PATH_APPSERVER /root/vpd.properties /opt/i /var/sadm/pkg/*WS* /usr/lib/objrepos/vpd.properties"

echo "###############################################"
echo "# Transfer Files for Base install"
echo "###############################################"
bn=`basename $image`
ssh $server "mkdir /opt/i"
scp $image $server:/opt/i/$bn
scp $scripts/appserver.response $server:/opt/i

echo "###############################################"
echo "# Unzipping Installation Image"
echo "###############################################"
ssh $server "unzip -q /opt/i/$bn -d /opt/i"

echo "###############################################"
echo "# Installing AppServer"
echo "###############################################"
nodename=`echo $server | cut -d. -f1`
echo nodename=$nodename
ssh $server "/opt/i/install -is:javahome /opt/i/jdk/java  -options /opt/i/appserver.response -W nodeNameBean.nodeName=$nodename -W nodeNameBean.hostName=$server"

echo ""
echo "###############################################"
echo "# Cleaning Up Installation"
echo "###############################################"
ssh $server "rm -fr /opt/i"

echo "###############################################"
echo "# Transfer Files for fixpack install"
echo "###############################################"
bn=`basename $fixpack`
ssh $server "mkdir /opt/i"
scp $fixpack $server:/opt/i/$bn

echo "###############################################"
echo "# Unzipping Fixpack Installation Image"
echo "###############################################"
ssh $server "unzip -q /opt/i/$bn -d /opt/i"

echo "###############################################"
echo "# Installing AppServer fixpack"
echo "###############################################"
ssh $server ". $PATH_APPSERVER/bin/setupCmdLine.sh && /opt/i/updateSilent.sh -installDir $PATH_APPSERVER -fixpack -install -fixpackDir /opt/i/fixpacks -fixpackID $fixpackid -skipIHS -skipMQ"

echo "###############################################"
echo "# Cleaning Up Installation"
echo "###############################################"
ssh $server "rm -fr /opt/i"

echo "###############################################"
echo "# Transfer Files for cumfix install"
echo "###############################################"
bn=`basename $cumfix`
ssh $server "mkdir /opt/i"
scp $cumfix $server:/opt/i/$bn

echo "###############################################"
echo "# Unzipping cumFix Installation Image"
echo "###############################################"
ssh $server "unzip -q /opt/i/$bn -d /opt/i"

echo "###############################################"
echo "# Installing AppServer cumfix"
echo "###############################################"
ssh $server ". $PATH_APPSERVER/bin/setupCmdLine.sh && /opt/i/updateSilent.sh -installDir $PATH_APPSERVER -fixpack -install -fixpackDir /opt/i/fixpacks -fixpackID $cumfixid -skipIHS -skipMQ"

echo "###############################################"
echo "# Cleaning Up Installation"
echo "###############################################"
ssh $server "rm -fr /opt/i"

echo "###############################################"
echo "# Transfer Files for jdk fixpack install"
echo "###############################################"
bn=`basename $jdkfix`
ssh $server "mkdir /opt/i"
scp $jdkfix $server:/opt/i/$bn

echo "###############################################"
echo "# Unzipping jdkFix Installation Image"
echo "###############################################"
ssh $server "unzip -q /opt/i/$bn -d /opt/i"

echo "###############################################"
echo "# Installing JDK fixpack"
echo "###############################################"
ssh $server ". $PATH_APPSERVER/bin/setupCmdLine.sh && /opt/i/updateSilent.sh -installDir $PATH_APPSERVER -fixpack -install -fixpackDir /opt/i/fixpacks -fixpackID $jdkfixid -skipIHS -skipMQ"

echo "###############################################"
echo "# Cleaning Up Installation"
echo "###############################################"
ssh $server "rm -fr /opt/i"


echo "###############################################"
echo "# Save Base WebSphere Installation"
echo "###############################################"
ssh $server "rm -f /opt/WebSphereAppServer.zip"
ssh $server "zip -qr /opt/WebSphereAppServer.zip $PATH_APPSERVER"

echo "###############################################"
echo "# Installation Complete"
echo "###############################################"
