#!/bin/bash

##########################################################################
# INTERNATIONAL BUSINESS MACHINES CORPORATION PROVIDES THIS SOFTWARE ON 
# AN "AS IS" BASIS AND IBM DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED, 
# INCLUDING, BUT NOT LIMITED TO, THE WARRANTY OF NON-INFRINGEMENT AND THE
# IMPLIED WARRANTIES OF  MERCHANTABILITY OR FITNESS FOR A PARTICULAR 
# PURPOSE.  IBM SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
# SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR OPERATION OF
# THIS SOFTWARE.  IBM HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, 
# UPDATES, ENHANCEMENTS OR MODIFICATIONS TO THE SOFTWARE.
##########################################################################

scripts=`dirname $0`
scripts=`cd $scripts;pwd`
. $scripts/serverConfig

server=$1
osname=`ssh $server uname`

echo "###############################################"
echo "# Installing XD DMgr on $server"
echo "# Operating System: $osname"
echo "###############################################"

if [ "$osname" = "Linux" ]; then
image=$XD_IMG_LINUX
osname=linux
isname=Linux
fi

if [ "$osname" = "SunOS" ]; then
image=$XD_IMG_SOLARIS
osname=sun
isname=Solaris
fi

if [ "$osname" = "AIX" ]; then
image=$XD_IMG_AIX
osname=aix
isname=AIX
fi

if [ "$image" = "" ]; then
echo Unsupported operating system: $osname
exit 1
fi

echo "###############################################"
echo "# Synchronize time"
echo "###############################################"
ssh $server "ntpdate -s pool.ntp.org"

echo "###############################################"
echo "# Stopping Deployment Manager"
echo "###############################################"
$scripts/stopDMgr

echo "###############################################"
echo "# Cleaning Up Deployment Manager Installation"
echo "###############################################"
ssh $server "rm -fr $PATH_DMGR /root/vpd.properties /opt/_id /var/sadm/pkg/*WS* /usr/lib/objrepos/vpd.properties"

echo "###############################################"
echo "# Restoring Base WebSphere Installation"
echo "###############################################"
ssh $server "unzip -q /opt/WebSphereDMgr.zip -d /"

echo "###############################################"
echo "# Transfer Files"
echo "###############################################"
bn=`basename $image`
ssh $server "mkdir /opt/_id"
scp $image $server:/opt/_id/$bn
scp $scripts/xd_dmgr.response $server:/opt/_id

echo "###############################################"
echo "# Unzipping XD Installation Image"
echo "###############################################"
ssh $server "unzip -q /opt/_id/$bn -d /opt/_id"


echo "###############################################"
echo "# Installing XD Dmgr Extensions"
echo "###############################################"
ssh $server ". $PATH_DMGR/bin/setupCmdLine.sh && /opt/_id/${isname}Installer.bin -options /opt/_id/xd_dmgr.response"

echo ""
echo "###############################################"
echo "# Cleaning Up Installation"
echo "###############################################"
ssh $server "rm -fr /opt/_id"

echo "###############################################"
echo "# Backup install logs"
echo "###############################################"
ssh $server "rm -rf $PATH_DMGR/install_logs"
ssh $server "mkdir $PATH_DMGR/install_logs"
ssh $server "cp -r $PATH_DMGR/logs/* $PATH_DMGR/install_logs"

echo "###############################################"
echo "# Installation Complete"
echo "###############################################"
