#!/bin/bash

##########################################################################
# INTERNATIONAL BUSINESS MACHINES CORPORATION PROVIDES THIS SOFTWARE ON 
# AN "AS IS" BASIS AND IBM DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED, 
# INCLUDING, BUT NOT LIMITED TO, THE WARRANTY OF NON-INFRINGEMENT AND THE
# IMPLIED WARRANTIES OF  MERCHANTABILITY OR FITNESS FOR A PARTICULAR 
# PURPOSE.  IBM SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
# SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR OPERATION OF
# THIS SOFTWARE.  IBM HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, 
# UPDATES, ENHANCEMENTS OR MODIFICATIONS TO THE SOFTWARE.
##########################################################################

scripts=`dirname $0`
scripts=`cd $scripts;pwd`
. $scripts/serverConfig

server=$1
osname=`ssh $server uname`

echo "###############################################"
echo "# Installing XD AppServer on $server"
echo "# Operating System: $osname"
echo "###############################################"

if [ "$osname" = "Linux" ]; then
image=$XD_IMG_LINUX
osname=linux
isname=Linux
fi

if [ "$osname" = "SunOS" ]; then
image=$XD_IMG_SOLARIS
osname=sun
isname=Solaris
fi

if [ "$osname" = "AIX" ]; then
image=$XD_IMG_AIX
osname=aix
isname=AIX
fi

if [ "$image" = "" ]; then
echo Unsupported operating system: $osname
exit 1
fi

echo "###############################################"
echo "# Synchronize time"
echo "###############################################"
ssh $server "ntpdate -s pool.ntp.org"

echo "###############################################"
echo "# Stopping node"
echo "###############################################"
$scripts/stopNode $server 

echo "###############################################"
echo "# Cleaning Up Node Installation"
echo "###############################################"
ssh $server "rm -fr $PATH_APPSERVER /opt/i /root/vpd.properties /var/sadm/pkg/*WS* /usr/lib/objrepos/vpd.properties"

echo "###############################################"
echo "# Restoring Base WebSphere Installation"
echo "###############################################"
ssh $server "unzip -q /opt/WebSphereAppServer.zip -d /"

echo "###############################################"
echo "# Transfer and unzip XD Installation Image"
echo "###############################################"
bn=`basename $image`
ssh $server "mkdir /opt/i"
scp $image $server:/opt/i/$bn
scp $scripts/xd_server.response $server:/opt/i
ssh $server "unzip -q /opt/i/$bn -d /opt/i"

echo "###############################################"
echo "# Installing XD Extensions"
echo "###############################################"
ssh $server ". $PATH_APPSERVER/bin/setupCmdLine.sh & /opt/i/${isname}Installer.bin -options /opt/i/xd_server.response"

echo ""
echo "###############################################"
echo "# Cleaning Up Installation"
echo "###############################################"
ssh $server "rm -fr /opt/i"

echo "###############################################"
echo "# Backup install logs"
echo "###############################################"
ssh $server "rm -rf $PATH_APPSERVER/install_logs"
ssh $server "mkdir $PATH_APPSERVER/install_logs"
ssh $server "cp -r $PATH_APPSERVER/logs/* $PATH_APPSERVER/install_logs"

echo "###############################################"
echo "# Installation Complete"
echo "###############################################"
